define php::fpm::pool (
  $user              = 'www-data',
  $group             = 'www-data',
  $ensure            = present,
  $listen_address    = '127.0.0.1',
  $listen_port       = 9000,
  $unix_socket_path  = false,
  $pm                = 'dynamic',
  $max_children      = 10,
  $start_servers     = 4,
  $min_spare_servers = 2,
  $max_spare_servers = 6,) {
  include php::fpm::service

  $file_name = "/etc/php5/fpm/pool.d/${name}.conf"

  #  notify { "php5-fpm-pool: $file_name": }
  $listen_unix_socket_path = "/var/run/php5-fpm.${name}.sock"

  #  class { "mdebug": message => $file_name }

  ini_setting { "${name}_pool_user":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'user',
    value   => $user,
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  } ->
  ini_setting { "${name}_pool_group":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'group',
    value   => $group,
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  } ->
  ini_setting { "${name}_pool_listen":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'listen',
    value   => $listen_unix_socket_path,
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  } ->
  ini_setting { "${name}_pool_listen.owner":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'listen.owner',
    value   => $user,
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  } ->
  ini_setting { "${name}_pool_listen.group":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'listen.group',
    value   => $group,
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  } ->
  # ####### Default Pool Settings
  # ####### REPLACE!!!!
  ini_setting { "${name}_pool_pm":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'pm',
    value   => 'dynamic',
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  } ->
  ini_setting { "${name}_pool_pm.max_children":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'pm.max_children',
    value   => '5',
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  } ->
  ini_setting { "${name}_pool_pm.start_servers":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'pm.start_servers',
    value   => '2',
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  } ->
  ini_setting { "${name}_pool_pm.min_spare_servers":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'pm.min_spare_servers',
    value   => '1',
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  } ->
  ini_setting { "${name}_pool_pm.max_spare_servers":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'pm.max_spare_servers',
    value   => '3',
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  } ->
  ini_setting { "${name}_pool_chdir":
    ensure  => present,
    path    => $file_name,
    section => $name,
    setting => 'chdir',
    value   => '/',
    require => Package["php5-fpm"],
    notify  => Class["php::fpm::service"],
  }
}
